@@ -1586,6 +1586,16 @@ class Dataset(HDXObject):
             else:
                 path = script_dir_plus_file('indicator_resource_view_template.yml', NotRequestableError)
         resourceview.update_from_yaml(path=path)
+
+        def replace_aggregate_col(hxl_preview_cfg, ind, colno):
+            aggregate_col_str = 'AGGREGATE_COL_%d' % colno
+            aggregate_col = ind.get('aggregate')
+            if aggregate_col:
+                replace = '"%s"' % aggregate_col
+            else:
+                replace = 'null'
+            return replace_string(hxl_preview_cfg, aggregate_col_str, replace)
+
         hxl_preview_config = resourceview['hxl_preview_config']
         if indicators is None:
             indicators_notexist = [False, False, False]
@@ -1605,6 +1615,7 @@ class Dataset(HDXObject):
                 hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_TITLE_1', indicator['title'])
                 replace = indicator.get('unit', '')
                 hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_UNIT_1', replace)
+                hxl_preview_config = replace_aggregate_col(hxl_preview_config, indicator, 1)
                 indicators_notexist[0] = False
             if len_indicators > 1 and indicators[1]:
                 indicator = indicators[1]
@@ -1614,6 +1625,7 @@ class Dataset(HDXObject):
                 hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_TITLE_2', indicator['title'])
                 replace = indicator.get('unit', '')
                 hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_UNIT_2', replace)
+                hxl_preview_config = replace_aggregate_col(hxl_preview_config, indicator, 2)
                 indicators_notexist[1] = False
             if len_indicators > 2 and indicators[2]:
                 indicator = indicators[2]
@@ -1623,6 +1635,7 @@ class Dataset(HDXObject):
                 hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_TITLE_3', indicator['title'])
                 replace = indicator.get('unit', '')
                 hxl_preview_config = replace_string(hxl_preview_config, 'INDICATOR_UNIT_3', replace)
+                hxl_preview_config = replace_aggregate_col(hxl_preview_config, indicator, 3)
                 indicators_notexist[2] = False
             if indicators_notexist == [True, True, True]:
                 return None
